@@ -22,7 +22,7 @@ from aliyunsdkcore.request import RpcRequest
 class DescribeClusterRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'eflo-controller', '2022-12-15', 'DescribeCluster','eflo')
+		RpcRequest.__init__(self, 'eflo-controller', '2022-12-15', 'DescribeCluster')
 		self.set_method('POST')
 
 	def get_ClusterId(self): # String
