@@ -22,7 +22,7 @@ from aliyunsdkcore.request import RpcRequest
 class DescribeZonesRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'eflo-controller', '2022-12-15', 'DescribeZones','eflo')
+		RpcRequest.__init__(self, 'eflo-controller', '2022-12-15', 'DescribeZones')
 		self.set_method('POST')
 
 	def get_AcceptLanguage(self): # String
